@@ -13,10 +13,19 @@ PRINTNANNY_BIN = environ.get("PRINTNANNY_BIN", "/usr/bin/printnanny")
 PRINTNANNY_DEBUG = environ.get("PRINTNANNY_DEBUG", False)
 PRINTNANNY_DEBUG = PRINTNANNY_DEBUG in ["True", "true", "1", "yes"]
 
-PRINTNANNY_PI: Optional[Pi] = None
+
+PRINTNANNY_CLOUD_PI: Optional[Pi] = None
 PRINTNANNY_CLOUD_NATS_CREDS = "/var/lib/printnanny/creds/printnanny-cloud-nats.creds"
 
 
+class PrintNannyApiConfig(TypedDict):
+    base_path: str
+    bearer_access_token: Optional[str]
+
+
+PRINTNANNY_CLOUD_API: Optional[PrintNannyApiConfig] = None
+
+
 class PrintNannyConfig(TypedDict):
     cmd: List[str]
     stdout: str
@@ -34,9 +43,19 @@ def deserialize_pi(pi_dict) -> Pi:
 def load_pi_model(pi_dict: Dict[str, Any]) -> Pi:
     result = deserialize_pi(pi_dict)
 
-    global PRINTNANNY_PI
-    PRINTNANNY_PI = result
-    return PRINTNANNY_PI
+    global PRINTNANNY_CLOUD_PI
+    PRINTNANNY_CLOUD_PI = result
+    return PRINTNANNY_CLOUD_PI
+
+
+def load_api_config(api_config_dict: Dict[str, str]) -> PrintNannyApiConfig:
+    global PRINTNANNY_CLOUD_API
+
+    PRINTNANNY_CLOUD_API = PrintNannyApiConfig(
+        base_path=api_config_dict.get("base_path", "https://printnanny.ai/"),
+        bearer_access_token=api_config_dict.get("bearer_access_token"),
+    )
+    return PRINTNANNY_CLOUD_API
 
 
 def load_printnanny_config() -> PrintNannyConfig:
@@ -76,17 +95,20 @@ def load_printnanny_config() -> PrintNannyConfig:
         config = json.loads(stdout)
         logger.debug("Parsed PrintNanny conf.d, loaded keys: %s", config.keys())
 
-        # try setting global PRINTNANNY_PI var
+        api_config = config.get("cloud", {}).get("api", {})
+
+        # try setting PRINTNANNY_CLOUD_API var
+        if api_config is not None:
+            load_api_config(api_config)
+        # try setting global PRINTNANNY_CLOUD_PI var
         pi = config.get("cloud", {}).get("pi")
         if pi is not None:
             load_pi_model(pi)
 
-        paths = config.get("paths", {}).get("lib_dir")
-        if paths is not None:
+        nats_creds = config.get("paths", {}).get("nats_creds")
+        if nats_creds is not None:
             global PRINTNANNY_CLOUD_NATS_CREDS
-            PRINTNANNY_CLOUD_NATS_CREDS = paths.get(
-                "nats_creds", PRINTNANNY_CLOUD_NATS_CREDS
-            )
+            PRINTNANNY_CLOUD_NATS_CREDS = nats_creds
 
     except json.JSONDecodeError as e:
         logger.warning(f"Failed to decode printnanny config: %", e)
